const Main = imports.ui.main;
const Me   = imports.misc.extensionUtils.getCurrentExtension();

const Ui    = Me.imports.ui;
const View  = Me.imports.view;
const Prefs = Me.imports.prefs;

let left   = {};
let right  = {};

let actors = [];

let workspaces   = {};
let applications = {};
let search       = {};

let undoApps   = {};
let undoSearch = {};

function init() {
    left = {
	    corner  : Ui.corner(Ui.LEFT),
	    ripples : Ui.ripples(Ui.LEFT),
	    animate : Ui.animate(Ui.LEFT),
        hook    : {}
    };
    right = {
	    corner  : Ui.corner(Ui.RIGHT),
	    ripples : Ui.ripples(Ui.RIGHT),
	    animate : Ui.animate(Ui.RIGHT),
        hook    : {}
    };
    
    actors = left.ripples.concat(right.ripples, left.corner, right.corner);

    workspaces = {
        command : View.activate,
        page    : View.workspaces
    };
    applications = {
        command : View.activate,
        page    : View.applications
    };
    search = {
        command : View.activate,
        page    : View.search
    };
}

function enable() {
    for (let i = 0; i < actors.length; ++i) {
	    Main.uiGroup.add_actor(actors[i]);
    }

    let animate = function(x) {
	    x.animate(x.corner, x.ripples);
    };

    let activate = function(x) {
	    x.command(x.page);
    };

    // this is a workaround
    animate(right);

    left.hook = left.corner.connect('enter-event', function() {
	    animate(left);
	    activate(applications);
    });    
    right.hook = right.corner.connect('enter-event', function() {
	    animate(right);
	    activate(workspaces)
    });

    undoApps = Prefs.onViewApps(function() {
	    activate(applications);
	});
    undoSearch = Prefs.onSearch(function() {
	    activate(search);
	});
}

function disable() {
    let disconnect = function(x) {
        x.corner.disconnect(x.hook);
    };

	disconnect(left);
    disconnect(right);

    undoApps();
    undoSearch();

    for (let i = 0; i < actors.length; ++i) {
	    Main.uiGroup.remove_actor(actors[i]);
    }
}
